# -#- coding: utf-8 -#-

from django.db import models
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _
from elephantblog.models import Category
from leonardo.module.web.models import Widget


class BlogCategoriesWidget(Widget):

    def get_categories(self):
        return Category.objects.all()

    class Meta:
        abstract = True
        verbose_name = _("blog categories")
        verbose_name_plural = _("blog categories")



# -#- coding: utf-8 -#-

from django.db import models
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _
from elephantblog.models import Entry
from leonardo.module.web.models import Widget


class RecentBlogPostsWidget(Widget):
    post_count = models.PositiveIntegerField(
        verbose_name=_("post count"), default=3)
    show_button = models.BooleanField(
        default=True, verbose_name=_("show link button"))

    def get_last_posts(self):
        return Entry.objects.all().order_by('-published_on')[:self.post_count]

    def get_all_posts(self):
        return Entry.objects.filter(published_on__in=[50, 60]).order_by('-published_on')

    class Meta:
        abstract = True
        verbose_name = _("recent blog posts")
        verbose_name_plural = _("recent blog posts")




from django.utils.translation import ugettext_lazy as _
from elephantblog.models import Entry
from leonardo.module import media, web

Entry.register_extensions('feincms.module.extensions.datepublisher',
                          'feincms.module.extensions.translations',
                          )
Entry.register_regions(
    ('main', _('Main content area')),
)

Entry.create_content_type(
    web.widget.HtmlTextWidget, regions=('main',), optgroup=_('Text'))
Entry.create_content_type(
    web.widget.MarkupTextWidget, regions=('main',), optgroup=_('Text'))

for widget in media.default.widgets:
    Entry.create_content_type(widget, regions=('main',), optgroup=_('Media'))




from django.apps import AppConfig

from .widget import *


default_app_config = 'leonardo.module.blog.BlogConfig'


class Default(object):

    optgroup = ('Blog')

    @property
    def apps(self):
        return [
            'leonardo.module.blog',
            'elephantblog',

        ]

    @property
    def widgets(self):
        return [
            BlogCategoriesWidget,
            RecentBlogPostsWidget,
        ]

    @property
    def plugins(self):
        return [
            ('elephantblog.urls', 'Blog'),
        ]


class BlogConfig(AppConfig, Default):
    name = 'leonardo.module.blog'
    verbose_name = ("Blog")

default = Default()



from haystack import indexes, fields

from elephantblog.models import Entry


class EntryIndex(indexes.SearchIndex, indexes.Indexable):

    url = fields.CharField(model_attr="get_absolute_url")
    text = fields.CharField(document=True, use_template=True)

    title = fields.CharField(model_attr="title")
    slug = fields.CharField(model_attr="slug")
    author = fields.CharField(model_attr="author")
    content = fields.CharField(model_attr="content")

    published_on = fields.DateTimeField(model_attr='published_on', null=True)
    last_changed = fields.DateTimeField(model_attr='last_changed', null=True)

    def should_update(self, instance, **kwargs):
        return instance.is_active()

    def get_model(self):
        return Entry

    def index_queryset(self, using=None):
        """Used when the entire index for model is updated."""
        return self.get_model().objects.filter(is_active=True)

    def get_updated_field(self):
        return "last_changed"




from django import template

register = template.Library()

from elephantblog.models import Entry

@register.filter
def lang(items, lang):
    return items.filter(published__gt=40).filter(language=lang)

@register.filter
def count(items, count):
    return items.order_by('-published_on')[:count]